cumulusci.tasks.github.tests package
====================================

Submodules
----------

cumulusci.tasks.github.tests.test_merge module
----------------------------------------------

.. automodule:: cumulusci.tasks.github.tests.test_merge
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.github.tests.util_github_api module
---------------------------------------------------

.. automodule:: cumulusci.tasks.github.tests.util_github_api
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.github.tests
    :members:
    :undoc-members:
    :show-inheritance:
